@@ -63,37 +63,9 @@ pub fn handler(
     schedule: TaskSchedule,
     bump: u8,
 ) -> ProgramResult {
-    // Get accounts.
-    let clock = &ctx.accounts.clock;
     let config = &ctx.accounts.config;
     let daemon = &mut ctx.accounts.daemon;
     let task = &mut ctx.accounts.task;
 
-    clock.unix_timestamp.checked_add(10).unwrap();
-
-    // Validate the task schedule.
-    require!(schedule.exec_at <= schedule.stop_at, ErrorCode::InvalidChronology);
-    require!(schedule.recurr >= 0, ErrorCode::InvalidRecurrNegative);
-    require!(schedule.recurr == 0 || schedule.recurr >= config.min_recurr, ErrorCode::InvalidRecurrBelowMin);
-
-    // Reject the instruction if it has other signers besides the daemon.
-    for acc in ix.accounts.as_slice() {
-        require!(
-            !acc.is_signer || acc.pubkey == daemon.key(), 
-            ErrorCode::InvalidSignatory
-        );
-    }
-
-    // Initialize task account.
-    task.daemon = daemon.key();
-    task.int = daemon.task_count;
-    task.ix = ix;
-    task.schedule = schedule;
-    task.status = TaskStatus::Queued;
-    task.bump = bump;
-
-    // Increment daemon task counter.
-    daemon.task_count = daemon.task_count.checked_add(1).unwrap();
-
-    return Ok(());
+    task.init(config, daemon, ix, schedule, bump)
 }
