@@ -6,7 +6,7 @@ mod instructions;
 
 use {anchor_lang::prelude::*, instructions::*, state::*};
 
-declare_id!("3qrr4WyYWLqbSi71HWTjKjk7RrGE4c1LaoD3t6kPAiek");
+declare_id!("4BrFhSiCd38uv8gdkv866cy7D3rq39i3ugK3fgXaA5W3");
 
 #[program]
 pub mod cronos {
@@ -19,12 +19,10 @@ pub mod cronos {
     pub fn admin_create_task(
         ctx: Context<AdminCreateTask>,
         ix: InstructionData,
-        exec_at: i64,
-        stop_at: i64,
-        recurr: i64,
+        schedule: TaskSchedule,
         bump: u8,
     ) -> ProgramResult {
-        admin_create_task::handler(ctx, ix, exec_at, stop_at, recurr, bump)
+        admin_create_task::handler(ctx, ix, schedule, bump)
     }
 
     pub fn admin_initialize(
@@ -99,8 +97,8 @@ pub mod cronos {
         fee_collect::handler(ctx)
     }
 
-    pub fn health_check(ctx: Context<HealthCheck>) -> ProgramResult {
-        health_check::handler(ctx)
+    pub fn health_ping(ctx: Context<HealthPing>) -> ProgramResult {
+        health_ping::handler(ctx)
     }
 
     pub fn task_cancel(ctx: Context<TaskCancel>) -> ProgramResult {
